#! /bin/sh
# %%%{CotEditorXInput=AllText}%%%

# **============================================================
# * 編集中のファイルを実行する.
# * 編集中のドキュメントについて、拡張子から判断し、実行する。
# * 対応拡張子
# * html          -> Safari にて表示
# * js            -> Safari にてスタブ用の html を使って実行
# * applescript   -> AppleScriptRunner による実行
# * sh            -> そのまま実行（ターミナル）
# * rb            -> ruby "filename.rb"（ターミナル）
# * pl            -> perl "filename.pl"（ターミナル）
# * php           -> php "filename.php"（ターミナル）
# * rst           -> 要 Sphinx 環境。make html 後 safari で ./_build/html/index.html を開く (ターミナル)
# *                  2012/03/26 add by Joey Chen
# * なお、このスクリプト自体は実行不可とした。
# * @author      odoru-saboten
# * @author      Tachi.K
# * @since       2010/11/03
# * @version     2012/03/29
# * @param       編集中のファイルの全てのテキスト
# * @return      エディタへのフィードバックなし
# ============================================================

INPUT=`cat -`

# ============================================================
# 編集中の書類のパスを得る
# ============================================================
osascript <<EOF
  set errorMsg to ""
  tell application "CotEditor"
    -- 書類を開いているか
    if not (exists front document) then
      set errorMsg to "対象のファイルを開いてください。"
      return
    else
      -- 書類のパスを得る
      set p to path of front document
      try
        if p is missing value then
          set p to ""
        end if
      on error
        set p to ""
      end try
      
      -- 書類は保存されているか（パス名が存在するか）
      if p is equal to "" then
        set errorMsg to "ファイルを保存してから実行してください。"
      else
        return p
      end if
    end if
  end tell
  tell application "System Events"
    activate
    display dialog errorMsg buttons {"OK"} default button 1 with icon 2
  end tell
EOF
DOCPATH=`osascript ~/Library/Application\ Support/CotEditor/getPath.applescript`
if [ "${DOCPATH}" = "" ]
then
  exit 0
fi

# ============================================================
# 書類情報を変数に設定する
# ============================================================
TMPPATH="${DOCPATH}.tmp.html"
DOCEXTENSION="${DOCPATH##*.}"
SCRIPTFILENAME=`basename "${DOCPATH}"`

# 拡張子判定

# ============================================================
# .php .pl .rb .sh（ターミナルで実行）
# ============================================================

# 実行のために必要なコマンド名
cmd_php="php"
cmd_pl="perl"
cmd_rb="ruby"
cmd_rst="make html"
cmd_sh=""

if [ "${DOCEXTENSION}" = "php" -o "${DOCEXTENSION}" = "pl" -o "${DOCEXTENSION}" = "rb" -o "${DOCEXTENSION}" = "sh" ]
then
  # 自分自身ではないことの確認
  if [ "$0" != "${DOCPATH}" ]
  then
  cmd=`eval 'echo $cmd_'${DOCEXTENSION}`
osascript <<EOF
  tell application "Terminal"
    activate
    set wList to properties of every window
    set listSize to count of wList
    if listSize < 1 then
      do script "${cmd} \"${DOCPATH}\""
    else
      do script "${cmd} \"${DOCPATH}\"" in front window
    end if
  end tell
EOF
  else
osascript <<EOF
  tell application "System Events"
    activate
    display dialog " '${SCRIPTFILENAME}' 自身は実行できません。" buttons {"OK"} default button 1 with icon 2
  end tell
EOF
  fi

# ============================================================
# .rst Sphinx ファイルとみなして、カレントディレクトリで make html を実行して、Safariでopenする
# 2012/03/26 add by Joey Chen
# ============================================================
elif [ "${DOCEXTENSION}" = "rst" ]
then
  # 自分自身ではないことの確認
  if [ "$0" != "${DOCPATH}" ]
  then
  cmd=`eval 'echo $cmd_'${DOCEXTENSION}`
osascript <<EOF
  tell application "Terminal"
    activate
    set wList to properties of every window
    set listSize to count of wList
    if listSize < 1 then
      do script "cd \"${DOCPATH%/*}\""
      do script "${cmd}"
    else
      do script "cd \"${DOCPATH%/*}\"" in front window
      do script "${cmd}" in front window
    end if
  end tell
EOF
osascript <<EOF
  tell application "Safari"
    activate
    open location "file://${DOCPATH%/*}/_build/html/index.html"
  end tell
EOF
  fi

# ============================================================
# .applescript  AppleScript Runner で実行
# ============================================================
elif [ "${DOCEXTENSION}" = "applescript" ]
then
osascript <<EOF
  tell application "AppleScript Runner"
    activate
    do script "${DOCPATH}"
  end tell
EOF

# ============================================================
# .html   Safari で開く
# ============================================================
elif [ "$DOCEXTENSION" = "html" -o "$DOCEXTENSION" = "htm" ]
then
# 編集中テキストを全て一時ファイルに
echo "${INPUT}" > "${TMPPATH}"

# AppleScript で Safari にファイルを開かせる
osascript <<EOF
	tell application "Safari"
		activate
		open location "file://${TMPPATH}"
	end tell
EOF

# 15 秒待ち、一時ファイルを削除する
sleep 15
rm "${TMPPATH}"

# ============================================================
# .js     Safari で実行
# ============================================================
elif [ "$DOCEXTENSION" = "js" ]
then
# 一時用 HTML ファイルの作成
a=`date +%s`
echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN"><html>' > "${TMPPATH}"
echo '<head><title>JAVASCRIPT_DEBUG</title>' >> "${TMPPATH}"
echo '<meta name="JAVASCRIPT_DEBUG" content="true" />' >> "${TMPPATH}"
echo '<script type="text/javascript" src="'${SCRIPTFILENAME}?a=${a}'"></script>' >> "${TMPPATH}"
echo '</head><body></body></html>' >> "${TMPPATH}"

# AppleScript で Safari にファイルを開かせる
osascript <<EOF
	tell application "Safari"
		activate
		open location "file://${TMPPATH}"
	end tell
EOF

# 15 秒待ち、一時ファイルを削除する
sleep 15
rm "${TMPPATH}"

# ============================================================
# いずれの拡張子でもない
# ============================================================
else
osascript <<EOF
  tell application "System Events"
    activate
    display dialog "Does not support command : '$DOCEXTENSION'" buttons {"OK"} default button 1 with icon 2
  end tell
EOF
  exit 1
fi
